==> xfe_0.66.orig.tar.gz: xfe-0.66/src/help.cc <==
#include "help.h"

// Help text
const char helptext[]=

"\n"
"\n"
"                                          XFE, X File Explorer File Manager\n"
"\n"
"                                       Copyright (C) 2002-2004 Roland Baudin\n"
"\n"
"                                            <http://xfe.sourceforge.net>\n"
"                                        <http://sourceforge.net/projects/xfe>\n"
"\n"
"\n"
"\n"
"\n"

"This program is free software; you can redistribute it and/or modify "
"it under the terms of the GNU General Public License as published by "
"the Free Software Foundation; either version 2, or (at your option) "
"any later version.\n"
"\n"
"\n"


"This program is distributed in the hope that it will be useful, "
"but WITHOUT ANY WARRANTY; without even the implied warranty of "
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the " 
"GNU General Public License for more details.\n"
"\n"
"\n"
  
"  Description\n"
" =-=-=-=-=-=\n"
"\n"
"X File Explorer (xfe) is a lightweight file manager for X11, written using the FOX toolkit.\n"
"It is desktop independent and can easily be customized.\n"
"It has Windows Commander or MS-Explorer style and it is very fast and small.\n"
"Xfe is based on the popular, but discontinued X Win Commander, written by Maxim Baranov.\n"
"\n"
"\n"

"  Features\n"
" =-=-=-=-=\n"
"\n"
"  - Four different file manager styles (one panel, two panels, tree list and one panel,\n"
"    tree list and two panels)\n"
"  - Integrated text viewer (X File View, xfv)\n"
"  - Integrated RPM viewer / installer / uninstaller (X File Query, xfq)\n"
"  - Status line\n"
"  - File associations\n"
"  - Auto save registry\n"
"  - Right mouse click pop-up menu in tree list and file list\n"
"  - Change file(s) attributes\n"
"  - Mount/Unmount devices (for Linux only)\n"
"  - Toolbar\n"
"  - Bookmarks\n"
"  - Color schemes (GNOME, KDE, Windows...)\n"
"  - Drag and Drop ( ctrl - copy, shift - move, alt - sym link )\n"
"  - Create / Extract archives (tar, zip, gzip, bzip2, compress formats are supported)\n"
"  - Tool tips for long file names\n"
"  - Progress bars or dialogs for lengthy file operations\n"
"\n"
"\n"

" Key bindings:\n"
" =-=-=-=-=-=\n"
"\n"
"	o Help\t\t\t\t\t- F1\n"
"	o View\t\t\t\t\t- F3, return\n"
"	o Edit\t\t\t\t\t\t- F4\n"
"	o Copy\t\t\t\t\t- F5, ctrl-c\n"
"	o Cut\t\t\t\t\t\t- ctrl-x\n"
"	o Paste\t\t\t\t\t- ctrl-v\n"
"	o Move\t\t\t\t\t- F6, ctrl-d\n"
"	o Rename\t\t\t\t\t- ctrl-n\n"
"	o Delete\t\t\t\t\t- F8, del, ctrl-del\n"
"	o Symlink\t\t\t\t\t- ctrl-s\n"
"	o New file\t\t\t\t\t- F2\n"
"	o New folder\t\t\t\t- F7\n"
"	o Properties\t\t\t\t\t- F9\n"
"	o Tree and one panel\t\t\t- ctrl-F1\n"
"	o Tree and two panels\t\t\t- ctrl-F2\n"
"	o One panel\t\t\t\t\t- ctrl-F3\n"
"	o Two panels\t\t\t\t- ctrl-F4\n"
"	o Hidden files\t\t\t\t- ctrl-F5\n"
"	o Hidden folders\t\t\t\t- ctrl-F6\n"
"	o Execute\t\t\t\t\t- ctrl-e\n"
"	o Go home\t\t\t\t\t- ctrl-h\n"
"	o Go up\t\t\t\t\t- backspace\n"
"	o Terminal\t\t\t\t\t- ctrl-t\n"
"	o Console file manager\t\t\t- ctrl-k\n"
"	o Refresh\t\t\t\t\t- ctrl-r\n"
"	o Select all\t\t\t\t\t- ctrl-a\n"
"	o Deselect all\t\t\t\t- ctrl-z\n"
"	o Invert selection\t\t\t\t- ctrl-i\n"
"	o Add bookmark\t\t\t\t- ctrl-b\n"
"	o Mount (Linux only)\t\t\t- ctrl-m\n"
"	o Unmount (Linux only)\t\t\t- ctrl-u\n"
"	o Quit\t\t\t\t\t- ctrl-q\n"
"\n"
"\n"

" Configuration\n"
" =-=-=-=-=-=-=\n"
"\n"
"Note you normally do not need to edit any configuration file by hand, "
"but this allows fine tweaking of the GUI parameters and can sometimes be "
"useful.\n"
"\n"

"By default system-wide configuration file Desktop is located in "
"/usr/local/lib/foxrc, which is overridden in ~/.foxrc/Desktop and "
"the latter is overridden in ~/.foxrc/Xfe.\n"
"\n"

"Every FOX application reads the file Desktop, but Xfe is specific to the "
"X File Explorer.\n"
"\n"

"If you need it, you can safely edit the configuration file to change "
"the defaults settings that are not accessible through the GUI. "
"For example, to change the wheel scrolling interval to 7 lines, "
"just modify the line 'wheellines=5' to 'wheellines=7' in the "
"[SETTINGS] section.\n"
"\n"

"PNG Icons are in /usr/local/lib/foxicons. You can change the path in " 
"Options->Change icon path.\n" 
"(you may want to change it, if Xfe is not installed in /usr/local)\n"
"\n"
"\n"

" Tips\n"
" =-=-=\n"
"\n"
"File list\n"
"	- Select files and right click to open a context menu on the selected files\n"
"	- Press ctrl + right click to open a context menu on the file panel\n"
"	- When dragging a file/folder to a folder, hold on the mouse on the folder to open it\n"
"\n"
"Tree list\n"
"	- Select a folder and right click to open a context menu on the selected folder\n"
"	- When dragging a file/folder to a folder, hold on the mouse on the folder to expand it\n"
"\n"
"\n"

" Bugs\n"
" =-=-=\n"
"\n"
"Please report bugs to me (roland65@free.fr).\n"
"\n"
"\n"

" Patches\n"
" =-=-=-=\n"
"\n"
"If you've done some interesting patch, please send it to me, "
" I will try to include it in the next release...\n"
"\n"
"\n"
"\n"

"[Many thanks to Maxim Baranov for his excellent X Win Commander "
"and to Guillaume Cottenceau for useful hacks.]\n"
"\n"
;

==> xfe-0.80.tar.gz: xfe-0.80/src/help.cc <==
#include "help.h"

// Help text
const char helptext[]=

"\n"
"\n"
"                                          XFE, X File Explorer File Manager\n"
"\n"
"                                       Copyright (C) 2002-2005 Roland Baudin\n"
"\n"
"                                            <http://roland65.free.fr/xfe>\n"
"                                        <http://sourceforge.net/projects/xfe>\n"
"\n"
"\n"
"\n"
"\n"

"This program is free software; you can redistribute it and/or modify "
"it under the terms of the GNU General Public License as published by "
"the Free Software Foundation; either version 2, or (at your option) "
"any later version.\n"
"\n"
"\n"


"This program is distributed in the hope that it will be useful, "
"but WITHOUT ANY WARRANTY; without even the implied warranty of "
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the " 
"GNU General Public License for more details.\n"
"\n"
"\n"
  
"  Description\n"
" =-=-=-=-=-=\n"
"\n"
"X File Explorer (xfe) is a lightweight file manager for X11, written using the FOX toolkit.\n"
"It is desktop independent and can easily be customized.\n"
"It has Windows Commander or MS-Explorer style and it is very fast and small.\n"
"Xfe is based on the popular, but discontinued X Win Commander, written by Maxim Baranov.\n"
"\n"
"\n"

"  Features\n"
" =-=-=-=-=\n"
"\n"
"  - Commander/Explorer interface with two file manager modes : a directory tree and one panel, or two panels\n"
"  - Integrated text viewer (X File View, xfv)\n"
"  - Integrated image viewer (X File Image, xfi)\n"
"  - Integrated RPM viewer / installer / uninstaller (X File Query, xfq)\n"
"  - Status line\n"
"  - File associations\n"
"  - Auto save registry\n"
"  - Right mouse click pop-up menu in tree list and file list\n"
"  - Change file(s) attributes\n"
"  - Mount/Unmount devices (for Linux only)\n"
"  - Toolbar\n"
"  - Bookmarks\n"
"  - Color schemes (GNOME, KDE, Windows...)\n"
"  - Drag and Drop ( ctrl - copy, shift - move, alt - sym link )\n"
"  - Create / Extract archives (tar, zip, gzip, bzip2, compress formats are supported)\n"
"  - Tool tips for long file names\n"
"  - Progress bars or dialogs for lengthy file operations\n"
"  - Thumbnails image previews\n"
"\n"
"\n"

" Key bindings:\n"
" =-=-=-=-=-=\n"
"\n"
"	o Help\t\t\t\t\t- F1\n"
"	o New file\t\t\t\t\t- F2\n"
"	o View\t\t\t\t\t- F3, return\n"
"	o Edit\t\t\t\t\t- F4\n"
"	o Copy\t\t\t\t\t- F5, ctrl-c\n"
"	o Cut\t\t\t\t\t\t- ctrl-x\n"
"	o Paste\t\t\t\t\t- ctrl-v\n"
"	o Move\t\t\t\t\t- F6, ctrl-d\n"
"	o Symlink\t\t\t\t\t- ctrl-s\n"
"	o Rename\t\t\t\t\t- ctrl-n\n"
"	o New folder\t\t\t\t- F7\n"
"	o Open\t\t\t\t\t- ctrl-o\n"
"	o Delete\t\t\t\t\t- F8, del\n"
"	o Go up\t\t\t\t\t- backspace\n"
"	o Properties\t\t\t\t- F9\n"
"	o Tree and one panel\t\t\t- ctrl-F1\n"
"	o Two panels\t\t\t\t- ctrl-F2\n"
"	o Large icons\t\t\t\t- F10\n"
"	o Small icons\t\t\t\t- F11\n"
"	o Detailed view\t\t\t\t- F12\n"
"	o Hidden folders\t\t\t\t- ctrl-F5\n"
"	o Hidden files\t\t\t\t- ctrl-F6\n"
"	o Thumbnails preview\t\t\t- ctrl-F7\n"
"	o Execute\t\t\t\t\t- ctrl-e\n"
"	o Go home\t\t\t\t\t- ctrl-h\n"
"	o Terminal\t\t\t\t\t- ctrl-t\n"
"	o Refresh\t\t\t\t\t- ctrl-r\n"
"	o Select all\t\t\t\t\t- ctrl-a\n"
"	o Deselect all\t\t\t\t- ctrl-z\n"
"	o Invert selection\t\t\t- ctrl-i\n"
"	o Add bookmark\t\t\t\t- ctrl-b\n"
"	o Mount (Linux only)\t\t\t- ctrl-m\n"
"	o Unmount (Linux only)\t\t- ctrl-u\n"
"	o Open file panel context menu\t- shift-F10\n"
"	o Quit\t\t\t\t\t- ctrl-q\n"
"\n"
"\n"

" Configuration\n"
" =-=-=-=-=-=-=\n"
"\n"
"Note you normally do not need to edit any configuration file by hand, "
"but this allows fine tweaking of the GUI parameters and can sometimes be "
"useful.\n"
"\n"

"By default system-wide configuration file Desktop is located in "
"/usr/local/lib/foxrc, which is overridden in ~/.foxrc/Desktop and "
"the latter is overridden in ~/.foxrc/Xfe.\n"
"\n"

"Every FOX application reads the file Desktop, but Xfe is specific to the "
"X File Explorer.\n"
"\n"

"If you need it, you can safely edit the configuration file to change "
"the defaults settings that are not accessible through the GUI. "
"For example, to change the wheel scrolling interval to 7 lines, "
"just modify the line 'wheellines=5' to 'wheellines=7' in the "
"[SETTINGS] section.\n"
"\n"

"PNG Icons are in /usr/local/lib/foxicons. You can change the path in " 
"Options->Change icon path.\n" 
"(you may want to change it, if Xfe is not installed in /usr/local)\n"
"\n"
"\n"

" Tips\n"
" =-=-=\n"
"\n"
"File list\n"
"	- Select files and right click to open a context menu on the selected files\n"
"	- Press ctrl + right click to open a context menu on the file panel\n"
"	- When dragging a file/folder to a folder, hold on the mouse on the folder to open it\n"
"\n"
"Tree list\n"
"	- Select a folder and right click to open a context menu on the selected folder\n"
"	- When dragging a file/folder to a folder, hold on the mouse on the folder to expand it\n"
"\n"
"\n"

" Bugs\n"
" =-=-=\n"
"\n"
"Please report bugs to me (roland65@free.fr).\n"
"\n"
"\n"

" Patches\n"
" =-=-=-=\n"
"\n"
"If you've done some interesting patch, please send it to me, "
" I will try to include it in the next release...\n"
"\n"
"\n"
"\n"

"[Many thanks to Maxim Baranov for his excellent X Win Commander "
"and to Guillaume Cottenceau for useful hacks.]\n"
"\n"
;
